@@ -4,10 +4,13 @@ import collections
 import json
 import os
 import re
+
+
 try:
     from urllib.request import Request, urlopen
 except ImportError:
     from urllib2 import Request, urlopen
+
 from pkg_resources import parse_version
 
 
@@ -15,7 +18,7 @@ def version_info(value):
     return tuple([int(i) for i in value.split(".") if i.isdigit()])
 
 
-__version__ = "1.0.9"
+__version__ = "1.0.12"
 __version_info__ = version_info(__version__)
 __title__ = "pgdoc-datatype-parser"
 __description__ = "PostgreSQL documentation data types parser."
@@ -24,8 +27,8 @@ PG_RELEASE_MIN_VERSION = (6, 3)
 PG_GH_RELEASES_URL = "https://api.github.com/repos/postgres/postgres/tags"
 PG_RELEASES_JSON_FILEPATH = os.path.join(
     os.path.dirname(__file__), "pg-releases.json")
-PG_DT_DOC_FILE_URLSCHEMA = "https://raw.githubusercontent.com/postgres/" \
-                         + "postgres/{commit_id}/doc/src/sgml/datatype.sgml"
+PG_DT_DOC_FILE_URLSCHEMA = ("https://raw.githubusercontent.com/postgres/"
+                            "postgres/{commit_id}/doc/src/sgml/datatype.sgml")
 
 
 def pg_release_name_to_version(release_name):
